@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
+  Copyright (C) 2001-2015 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -145,7 +145,7 @@ extern "C" {
 
 #endif
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(__GNUC__)
 #define alloca _alloca
 #endif
 
@@ -167,15 +167,15 @@ extern "C" {
   int osip_atoi (const char *number);
   int osip_strcasecmp (const char *s1, const char *s2);
   int osip_strncasecmp (const char *s1, const char *s2, size_t len);
-  char *osip_strcasestr (const char *haystack, const char *needle);
 
 #else
 #define osip_atoi  atoi
 #define osip_strcasecmp  strcasecmp
 #define osip_strncasecmp  strncasecmp
-#define osip_strcasestr  strcasestr
 #endif
 
+  char *osip_strcasestr (const char *haystack, const char *needle);
+
 /**************************/
 /* STRING support         */
 /**************************/
@@ -185,10 +185,9 @@ extern "C" {
   char *osip_strdup_without_quote (const char *ch);
   int osip_tolower (char *word);
   int osip_clrspace (char *word);
-  char *__osip_sdp_append_string (char *string, size_t size, char *cur, char *string_osip_to_append);
   int __osip_set_next_token (char **dest, char *buf, int end_separator, char **next);
   /* find the next unescaped quote and return its index. */
-  char *__osip_quote_find (const char *qstring);
+  const char *__osip_quote_find (const char *qstring);
   char *osip_enquote (const char *s);
   void osip_dequote (char *s);
 
@@ -231,7 +230,7 @@ extern "C" {
    without trace */
   void osip_trace_initialize_func (osip_trace_level_t level, osip_trace_func_t * func);
   void osip_trace_initialize_syslog (osip_trace_level_t level, char *ident);
-  void osip_trace_initialize (osip_trace_level_t level, FILE * file);
+  int osip_trace_initialize (osip_trace_level_t level, FILE * file);
   void osip_trace_enable_until_level (osip_trace_level_t level);
   void osip_trace_enable_level (osip_trace_level_t level);
   void osip_trace_disable_level (osip_trace_level_t level);
